/*--------------------------------------------------------------------------------------+
|
|  $Source: MstnExamples/Annotations/ModifyTextTool/ChangeText.cpp $
|
|  $Copyright: (c) 2020 LA Solutions Ltd. All rights reserved. $
|  $Copyright: (c) 2016 Bentley Systems, Incorporated. All rights reserved. $
|
+--------------------------------------------------------------------------------------*/

/*-------------------------------------------------------------------------------------+
| ChangeText application source                                                 		|
+--------------------------------------------------------------------------------------*/

/*-------------------------------------------------------------------------------------+
|                                                                                      |
| This file has class which contains main application logic of Change case             |
| e.g. changing text to user-supplied string                             				|
+-------------------------------------------------------------------------------------*/

#pragma once
#include <Mstn/MdlApi/MdlApi.h>
#include <DgnView/AccuDraw.h>
#include <DgnPlatform/ITextEdit.h>
#include <DgnPlatform/TextHandlers.h>

#include "ITextModify.h"
#include "ModifyTextTool.h"
#include "ModifyTextToolIds.h"

USING_NAMESPACE_BENTLEY_DGNPLATFORM;

/*=================================================================================**//**
* @bsiclass                                                               Bentley Systems
+===============+===============+===============+===============+===============+======*/

/*---------------------------------------------------------------------------------**//**
* Function cotaining pure application logic of the tool i.e. changing case of the
* Text element to upper case or to lower case.
* Returns status of the operation. SUCCESS on successfully changing the text in Text block.
*
* @param[out]        eeh               Handle of the Text element which is to be operated.
* @param[out]        m_textBlock       Text block containig text whose case needs to be change.

+---------------+---------------+---------------+---------------+---------------+--*/
StatusInt ChangeText::ModifyText(TextBlockR m_textBlock)
{
	if (m_textBlock.IsEmpty())
		return ERROR;

	WString planeString = m_textBlock.ToString();

	WString regEx;
	TextBlock::FindTextParametersPtr findParams;

	// Check if the string of the Text block has lower case.
	if ((m_textBlock.FindText(regEx.c_str(), findParams.get(), m_textBlock.CreateStartCaret().get(), nullptr)).IsValid())
		planeString.ToUpper();
	else
		planeString.ToLower();

	CaretPtr startCaret = m_textBlock.CreateStartCaret();
	CaretPtr endCaret = m_textBlock.CreateEndCaret();

	//Replace the text in text block with the updated upper case text
	m_textBlock.ReplaceText(planeString.c_str(), *startCaret, *endCaret);

	return SUCCESS;
}
/*---------------------------------------------------------------------------------**//**
* The user is prompted for appropriate actions based on the state the tool.
* Similarly, AccuDraw features are enabled/disabled based on the state of the tool.
*
* @param[in]        m_toolState       Parameters required set the current state of the tool.

+---------------+---------------+---------------+---------------+---------------+--*/
void ChangeText::SetupAndPromptForNextAction(ModifyToolState m_toolState)
{
	WString promptMessage;
	switch (m_toolState)
	{
		case ModifyToolState::TOOLSTATE_Locating:
			{
			AccuSnap::GetInstance().EnableLocate(true);
			AccuSnap::GetInstance().EnableSnap(false);
			RmgrResource::LoadWString(promptMessage, 0, STRINGLISTID_ChangeTextMessages, PROMPT_SELECT_ELEMENT);
			NotificationManager::OutputPrompt(promptMessage.c_str());
			break;
			}
		case ModifyToolState::TOOLSTATE_Dynamics:
			{
			AccuSnap::GetInstance().EnableLocate(false);
			AccuSnap::GetInstance().EnableSnap(true);
			RmgrResource::LoadWString(promptMessage, 0, STRINGLISTID_ChangeTextMessages, PROMPT_ACCEPT_ELEMENT);
			NotificationManager::OutputPrompt(promptMessage.c_str());
			break;
			}
		default:
			break;
	}
}
/*---------------------------------------------------------------------------------**//**
* Returns true if the Textblock contains lower/upper string.
* Uses regular expression to find the lower/upper case alphabets of the string in the Textblock.
* Function returns true on valid selection of text.
* @param[in]        textBlock       Parameters required which gives the string form the Text element to check for lower/upper case.

+---------------+---------------+---------------+---------------+---------------+--*/
bool ChangeText::IsSelectionValid(TextBlockCR textBlock)
{
	if (textBlock.IsEmpty())
		return false;

	return true;
}

