/*--------------------------------------------------------------------------------------+
|
|  $Source: MstnExamples/Annotations/ModifyTextTool/ITextModify.h $
|
|  $Copyright: (c) 2016 Bentley Systems, Incorporated. All rights reserved. $
|
+--------------------------------------------------------------------------------------*/

#pragma once

/*----------------------------------------------------------------------------------**//**
* Enum contains values used for setting the current state of the tool.
+---------------+---------------+---------------+---------------+---------------+--*/
enum class ModifyToolState
    {
    TOOLSTATE_Locating = 0,
    TOOLSTATE_Dynamics = 1
    };

/*----------------------------------------------------------------------------------**//**
* Enum used to know that which type of object needs to be created depending upon enum
* value passed.
+---------------+---------------+---------------+---------------+---------------+--*/
enum class ModifyTextOperation
    {
    CHANGECASE = 0,
    CHANGETEXT,
    };

/*----------------------------------------------------------------------------------**//**
* In order to work with the generic ModifyTextTool,the classes (which involve copy
*.and modification of a Text elements) should derive from this interface.
+---------------+---------------+---------------+---------------+---------------+--*/
class IModifyText : public RefCountedBase
    {

    public: virtual StatusInt ModifyText(TextBlockR m_textBlock) = 0;
    public: virtual void SetupAndPromptForNextAction(ModifyToolState m_toolState) = 0;
    public: virtual bool IsSelectionValid(TextBlockCR textBlock) = 0;

    };

typedef RefCountedPtr<IModifyText> IModifyTextPtr;

/*----------------------------------------------------------------------------------**//*
* Factory for creating objects derived from IModifyText
+---------------+---------------+---------------+---------------+---------------+--*/
class ModifyFactory
{
    public: static IModifyTextPtr CreateTextModify(ModifyTextOperation toolText);
};