/*--------------------------------------------------------------------------------------+
|
|  $Source: MstnExamples/Annotations/ModifyTextTool/ModifyTextTool.cpp $
|
|  $Copyright: (c) 2020 LA Solutions Ltd. All rights reserved. $
|  $Copyright: (c) 2016 Bentley Systems, Incorporated. All rights reserved. $
|
+--------------------------------------------------------------------------------------*/

/*-------------------------------------------------------------------------------------+
| ModifyTextTool application source                                                    |
+--------------------------------------------------------------------------------------*/

#pragma once
#include <Mstn/MdlApi/MdlApi.h>
#include <DgnView/AccuDraw.h>
#include <DgnView/DgnElementSetTool.h>
#include <DgnPlatform/ITextEdit.h>
#include <DgnPlatform/TextHandlers.h>

#include "ModifyTextTool.h"
#include "ModifyTextToolIds.h"
#include "ModifyTextToolcmd.h"
#include "ITextModify.h"

USING_NAMESPACE_BENTLEY_DGNPLATFORM;

/*---------------------------------------------------------------------------------**//**
* Factory method which creates object of class implementing IModifyText class.
* Returns object of class depending on parameter passed.
*
* @param[in]        toolText            Parameter required to know object of which class needs to be return.
+---------------+---------------+---------------+---------------+---------------+--*/
IModifyTextPtr ModifyFactory::CreateTextModify(ModifyTextOperation toolText)
{
	switch (toolText)
	{
		case ModifyTextOperation::CHANGECASE:
			return ChangeCase::Create();
		case ModifyTextOperation::CHANGETEXT:
			return ChangeText::Create();
	}
	return nullptr;
}
/*---------------------------------------------------------------------------------**//**
* Map: key-in to function
* Commands
+---------------+---------------+---------------+---------------+---------------+--*/
MdlCommandNumber s_commandNumbers[] =
    {
            {(CmdHandler) ChangeCase_start, CMD_CHANGECASE},
            {(CmdHandler) ChangeText_start, CMD_CHANGETEXT},
            0
    };


/*---------------------------------------------------------------------------------**//**
* MdlMain
*
* @param[in]        argc        The number of command line parameters sent to the application.
* @param[in]        argv[]      The array of strings sent to the application on the command line.
*
* @bsimethod                                                              Bentley Systems
+---------------+---------------+---------------+---------------+---------------+--*/
extern "C" DLLEXPORT  void MdlMain(int argc, WCharCP argv[])
    {
    /* Open the resource file.*/
    RscFileHandle   rfHandle;
    mdlResource_openFile(&rfHandle, nullptr, RSC_READONLY);

    /* Register commands */
    mdlSystem_registerCommandNumbers(s_commandNumbers);
    mdlParse_loadCommandTable(nullptr);
    };