#include <DgnPlatform/ITextEdit.h>
#include <DgnPlatform/TextHandlers.h>

#include "ITextModify.h"

void ChangeText_start(WCharCP /*unparsed*/);
void ChangeCase_start(WCharCP /*unparsed*/);

/*---------------------------------------------------------------------------------**//**
* Class implementing IModifyText class and ModifyText method having core logic of
* changing case of the selected Text element.
+---------------+---------------+---------------+---------------+---------------+--*/
struct ChangeCase : public IModifyText
{
	/*---------------------------------------------------------------------------------**//**
	* Enum with which we can decide which regular expression (LOWECASE or UPPERCASE)
	* is to be assigned to validate the selected Text element.
	+---------------+---------------+---------------+---------------+---------------+--*/
	enum class ChangeCaseOperation
	{
		LOWERCASE = 0,
		VALIDATE,
	};


    public: static IModifyText* Create() { return (IModifyText*) new ChangeCase(); };

    private: ChangeCase() {};

    public: ~ChangeCase() {};

/*---------------------------------------------------------------------------------**//**
* Function cotainig pure application logic of the tool i.e. changing case of the
* Text element to upper case or to lower case.
* Returns status of the operation. SUCCESS on successfully changing the text in Text block.
*
* @param[out]        eeh               Handle of the Text element which is to be operated.
* @param[out]        m_textBlock       Text block containing text whose case needs to be changed.

+---------------+---------------+---------------+---------------+---------------+--*/
    public:virtual StatusInt ModifyText(TextBlockR m_textBlock);
/*---------------------------------------------------------------------------------**//**
* The user is prompted for appropriate actions based on the state the tool.
* Similarly, AccuDraw features are enabled/disabled based on the state of the tool.
*
* @param[in]        m_toolState       Parameters required set the current state of the tool.

+---------------+---------------+---------------+---------------+---------------+--*/
    public:void SetupAndPromptForNextAction(ModifyToolState m_toolState);
/*---------------------------------------------------------------------------------**//**
* Returns true if the Textblock contains lower/upper string.
* Uses regular expression to find the lower/upper case alphabets of the string in the Textblock.
* Function returns true on valid selection of text.
* @param[in]        textBlock       Parameters required which gives the string form the Text element to check for lower/upper case.

+---------------+---------------+---------------+---------------+---------------+--*/
    public:bool IsSelectionValid(TextBlockCR textBlock);
/*---------------------------------------------------------------------------------**//**
* Creates a regular expression to find lower/upper alphabetic portion of a string
* or to validate the string within a Textblock.
* Sets the regular expression as a find parameter.
*
* @param[out]        regEx            Regular expression to find lower alphabetic portion of the string in a Text block.
* @param[out]        findParams       Parameters required to find lower alphabetic portion of the string in a Text block.
* @param[in]        changeCaseOp       Parameters required to determine which regular expression is to assign for validating the string in the Text block.

+---------------+---------------+---------------+---------------+---------------+--*/
	public: void SetupForFind(WStringR regEx, Bentley::DgnPlatform::TextBlock::FindTextParametersPtr& findParams, ChangeCaseOperation changeCaseOp);
};

/*---------------------------------------------------------------------------------**//**
* Class implementing IModifyText class and ModifyText method having core logic of
* changing the selected Text element.
+---------------+---------------+---------------+---------------+---------------+--*/
struct ChangeText : public IModifyText
{
    public: static IModifyText* Create() { return (IModifyText*) new ChangeText(); };

    private: ChangeText() {};

    public: ~ChangeText() {};

/*---------------------------------------------------------------------------------**//**
* Function cotainig pure application logic of the tool i.e. changing case of the
* Text element to upper case or to lower case.
* Returns status of the operation. SUCCESS on successfully changing the text in Text block.
*
* @param[out]        eeh               Handle of the Text element which is to be operated.
* @param[out]        m_textBlock       Text block containing text to be changed.

+---------------+---------------+---------------+---------------+---------------+--*/
    public:virtual StatusInt ModifyText(TextBlockR m_textBlock);
/*---------------------------------------------------------------------------------**//**
* The user is prompted for appropriate actions based on the state the tool.
* Similarly, AccuDraw features are enabled/disabled based on the state of the tool.
*
* @param[in]        m_toolState       Parameters required set the current state of the tool.

+---------------+---------------+---------------+---------------+---------------+--*/
    public:void SetupAndPromptForNextAction(ModifyToolState m_toolState);
/*---------------------------------------------------------------------------------**//**
* Returns true if the Textblock contains lower/upper string.
* Uses regular expression to find the lower/upper case alphabets of the string in the Textblock.
* Function returns true on valid selection of text.
* @param[in]        textBlock       Parameters required which gives the string form the Text element to check for lower/upper case.

+---------------+---------------+---------------+---------------+---------------+--*/
    public:bool IsSelectionValid(TextBlockCR textBlock);
};